@@ -51,7 +51,7 @@ def countIssue(dt_upt, df_agg_issue):
             dates = dates - timedelta(days=7)
             
         df_issue = pd.DataFrame(list(dict_issue_weekly.items()), columns=['User Name','Issue Total'])
-        save = df_issue.to_csv(r'E:/TA/Hasil/Issue/Base/issue_week{counter}.csv'.format(counter = week), index = None, header= True)
+        save = df_issue.to_csv(r'app/hasil/Issue/Base/issue_week{counter}.csv'.format(counter = week), index = None, header= True)
         dates = dates + timedelta(days=7)
         
     return week
@@ -77,7 +77,7 @@ def countPR(dt_upt, df_agg_pull):
                         dict_pull_weekly[df_agg_pull['User Name'][i]] = dict_pull_weekly[df_agg_pull['User Name'][i]] + pull
                     
                     df_pull = pd.DataFrame(list(dict_pull_weekly.items()), columns=['User Name','PR Total'])
-                    save = df_pull.to_csv(r'E:/TA/Hasil/Pull/Base/PR_week{counter}.csv'.format(counter = week), index = None, header= True)
+                    save = df_pull.to_csv(r'app/hasil/Pull/Base/PR_week{counter}.csv'.format(counter = week), index = None, header= True)
                     break; break
 
                 dates = dates + one_day
@@ -105,7 +105,7 @@ def countCommit(api_contributor):
             commit = api_contributor[i]['weeks'][j]['c']
             dict_commit_weekly[api_contributor[i]['author']['login']] = commit
             df_commit = pd.DataFrame(list(dict_commit_weekly.items()), columns=['User Name','Commit Total'])
-            save = df_commit.to_csv(r'E:/TA/Hasil/Commit/Base/commit_week{counter}.csv'.format(counter = weeks), index = None, header= True)
+            save = df_commit.to_csv(r'app/hasil/Commit/Base/commit_week{counter}.csv'.format(counter = weeks), index = None, header= True)
 
 def countLOC(api_contributor):
     
@@ -119,4 +119,4 @@ def countLOC(api_contributor):
             loc += api_contributor[i]['weeks'][j]['d']
             dict_loc_weekly[api_contributor[i]['author']['login']] = loc
             df_loc = pd.DataFrame(list(dict_loc_weekly.items()), columns=['User Name','LOC Total'])
-            save = df_loc.to_csv(r'E:/TA/Hasil/LOC/Base/LOC_week{counter}.csv'.format(counter = weeks), index = None, header= True)
\ No newline at end of file
+            save = df_loc.to_csv(r'app/hasil/LOC/Base/LOC_week{counter}.csv'.format(counter = weeks), index = None, header= True)
\ No newline at end of file
